========
Overview
========

NBAWebStats is a Python interface to the stats.nba.com HTTP API, compatible with
Python 2.6-2.7 and 3.3-3.5.

NBAWebStats was developed from existing packages for the same purpose such as
`py-goldsberry`__, without which NBAWebStats would not be possible. Compared to
py-goldsberry, NBAWebStats offers the following attributes:

__ http://github.com/bradleyfay/py-Goldsberry

* Interface adherent to :pep:`8`.
* Smaller, more maintainable code footprint due to reduced boilerplate (single
  ~200 line python file vs 10 files totalling ~2350 lines).
* Centralized documentation of permitted request types.
* Descriptive package name.

Details
-------

* Source repository: http://github.com/agirardeaudale/nbawebstats
* Documentation: https://nbawebstats.readthedocs.org.
* Free software: MIT license
